'use strict';

Object.defineProperty(exports, '__esModule', { value: true });

var react = require('react');

function useDebounce(value, delay) {
  if (delay === void 0) {
    delay = 500;
  }

  var _useState = react.useState(value),
      debouncedValue = _useState[0],
      setDebouncedValue = _useState[1];

  react.useEffect(function () {
    var handler = setTimeout(function () {
      setDebouncedValue(value);
    }, delay);
    return function () {
      return clearTimeout(handler);
    };
  }, [delay, value]);
  return debouncedValue;
}

function useIsMounted() {
  var mountedRef = react.useRef(false);
  var isMounted = react.useCallback(function () {
    return mountedRef.current;
  }, []);
  react.useEffect(function () {
    mountedRef.current = true;
    return function () {
      mountedRef.current = false;
    };
  }, []);
  return isMounted;
}

function useSafeState(initialState) {
  var isMounted = useIsMounted();

  var _useState = react.useState(initialState),
      state = _useState[0],
      setState = _useState[1];

  var safeSetState = react.useCallback(function (value) {
    if (isMounted()) {
      setState(value);
    }
  }, [isMounted]);
  return [state, safeSetState];
}

function usePrevious(value) {
  // Store current value in ref
  var ref = react.useRef();
  react.useEffect(function () {
    // Update the value if it changes
    ref.current = value;
  }, [value]); // return the previous value

  return ref.current;
}

function _extends() {
  _extends = Object.assign || function (target) {
    for (var i = 1; i < arguments.length; i++) {
      var source = arguments[i];

      for (var key in source) {
        if (Object.prototype.hasOwnProperty.call(source, key)) {
          target[key] = source[key];
        }
      }
    }

    return target;
  };

  return _extends.apply(this, arguments);
}

function useLegacyState(initialState) {
  return react.useReducer(function (state, update) {
    return _extends({}, state, update);
  }, initialState);
}

exports.useDebounce = useDebounce;
exports.useIsMounted = useIsMounted;
exports.useLegacyState = useLegacyState;
exports.usePrevious = usePrevious;
exports.useSafeState = useSafeState;
//# sourceMappingURL=react-use-custom-hooks.cjs.development.js.map
